@@ -26,6 +26,19 @@ COL_TASK_PROGRESS = "Progress"
 COL_HORIZON_START = "Horizon Start"
 COL_HORIZON_END = "Horizon End"
 
+EXCEL_COL_NAMES_V0 = {
+    COL_TASK_ID: "Task ID",
+    COL_TASK_NAME: "Task Name",
+    COL_TASK_ES: "ES",
+    COL_TASK_LF: "LF",
+    COL_TASK_START: "Task Start",
+    COL_TASK_FINISH: "Task Finish",
+    COL_TASK_WEEK_PREFIX: "Week ",
+    COL_TASK_PROGRESS: "Progress",
+    COL_TASK_EFFORT: "Effort (weeks)",
+    COL_HORIZON_START: "Horizon Start",
+    COL_HORIZON_END: "Horizon End",
+}
 
 EXCEL_COL_NAMES = {
     COL_TASK_ID: "Task ID",
